==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dock-network-plugin/translations/dock-network-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Lloj Sigurie</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Po bëhet mirëfilltësim</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Po merret adresë IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>E lidhur</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>E shkëputur</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>U dështua</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Po merret adresë</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Lidhja dështoi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Çaktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Çaktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dock-network-plugin/translations/dock-network-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Lidhu me rrjet të fshehur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Emër (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Lloj Sigurie</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Po bëhet mirëfilltësim</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Po merret adresë IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>E lidhur</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>E shkëputur</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>U dështua</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Po merret adresë</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Lidhja dështoi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Çaktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Çaktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
</context>
</TS>
